@@ -275,6 +275,9 @@ precision <- function(x) {
   rng <- range(x, na.rm = TRUE)
 
   span <- if (zero_range(rng)) abs(rng[1]) else diff(rng)
+  if (span == 0)
+    return(1)
+
   10 ^ floor(log10(span))
 }
 
